/*
 * Copyright 2024 YugaByte, Inc. and Contributors
 */
import clsx from 'clsx';
import { Box, Tab, Tabs, makeStyles } from '@material-ui/core';
import { TabContext, TabPanel } from '@material-ui/lab';
import { isNonEmptyArray } from '@yugabytedb/ui-components';
import { PrimaryDashboard } from './PrimaryDashboard';
import { Anomaly, AppName, PrimaryDashboardViewTabs } from '../helpers/dtos';

const useStyles = makeStyles((theme) => ({
  tabButton: {
    padding: '12px 16px',
    width: '210px',
    height: '40px',
    boxSizing: 'border-box',
    borderRadius: '8px'
  },
  selectedTab: {
    margin: '0 -1px',
    backgroundColor: '#F7F7F7',
    border: '1px solid #C8C8C8'
  },
  tabLabelWrapper: {
    alignItems: 'flex-start',
    padding: '12px 16px',
    fontSize: '13px',
    fontWeight: 400,
    textTransform: 'none',
    color: '#232329'
  },
  tabPanel: {
    padding: '32px'
  },
  noTabBorder: {
    borderBottom: 'unset'
  },
  tabBox: {
    border: `1px solid ${theme.palette.grey[300]}`,
    borderRadius: '8px'
  }
}));

interface PrimaryDashboardTabsProps {
  filteredAnomalyList: Anomaly[];
  currentTab: PrimaryDashboardViewTabs;
  universeUuid: string;
  appName: AppName;
  timezone?: string;
  onSelectedIssue?: (troubleshootUuid: string) => void;
  handleResolve: (key: string, value: boolean) => void;
  onTabChange: (tab: PrimaryDashboardViewTabs) => void;
}

export const PrimaryDashboardTabs = ({
  filteredAnomalyList,
  currentTab,
  universeUuid,
  appName,
  timezone,
  onSelectedIssue,
  handleResolve,
  onTabChange
}: PrimaryDashboardTabsProps) => {
  const classes = useStyles();

  const handleTabChange = (_event: React.ChangeEvent<{}>, newTab: PrimaryDashboardViewTabs) => {
    onTabChange(newTab);
  };

  return (
    <TabContext value={currentTab}>
      <Box className={classes.tabBox}>
        <Box>
          <Tabs
            classes={{ root: classes.noTabBorder }}
            orientation="horizontal"
            onChange={handleTabChange}
          >
            <Tab
              classes={{
                root: clsx(
                  classes.tabButton,
                  currentTab === PrimaryDashboardViewTabs.ANOMALY && classes.selectedTab
                ),
                wrapper: classes.tabLabelWrapper
              }}
              label={PrimaryDashboardViewTabs.ANOMALY}
              value={PrimaryDashboardViewTabs.ANOMALY}
            />
            <Tab
              classes={{
                root: clsx(
                  classes.tabButton,
                  currentTab === PrimaryDashboardViewTabs.QUERY && classes.selectedTab
                ),
                wrapper: classes.tabLabelWrapper
              }}
              label={PrimaryDashboardViewTabs.QUERY}
              value={PrimaryDashboardViewTabs.QUERY}
            />
          </Tabs>
        </Box>
        <Box width="100%">
          <TabPanel classes={{ root: classes.tabPanel }} value={PrimaryDashboardViewTabs.ANOMALY}>
            {isNonEmptyArray(filteredAnomalyList) ? (
              filteredAnomalyList?.map((rec: any) => (
                <>
                  <PrimaryDashboard
                    key={rec.uuid}
                    idKey={rec.uuid}
                    uuid={rec.uuid}
                    category={rec.category}
                    data={rec}
                    resolved={!!rec.isResolved}
                    onResolve={handleResolve}
                    universeUuid={universeUuid}
                    appName={appName}
                    timezone={timezone}
                    onSelectedIssue={onSelectedIssue}
                  />
                </>
              ))
            ) : (
              <Box>
                <span>{'There are no issues with the current universe'}</span>
              </Box>
            )}
          </TabPanel>
          <TabPanel classes={{ root: classes.tabPanel }} value={PrimaryDashboardViewTabs.QUERY}>
            <Box>{'hello'}</Box>
          </TabPanel>
        </Box>
      </Box>
    </TabContext>
  );
};
