import { Box, makeStyles, Typography } from '@material-ui/core';
import { Anomaly, AppName, GraphResponse, GraphType, MetricMeasure } from '../helpers/dtos';
import { SecondaryDashboard } from './SecondaryDashboard';
import { getOperations } from '../helpers/utils';
import { YBPanelItem } from '@yugabytedb/ui-components';

interface QueryDataViewProps {
  queryId: string[] | undefined;
  anomalyData: Anomaly | null;
  metricMeasure: string;
  universeQueryData: any;
  appName: AppName;
  timezone?: string;
  graphData: GraphResponse[] | null;
  graphQueryParams: any;
  onSelectAshLabel: (groupByLabel: string, metricData: any, isAdvancedView?: boolean) => void;
}

const useStyles = makeStyles((theme) => ({
  queryText: {
    marginLeft: theme.spacing(4)
  }
}));

export const QueryDataView = ({
  queryId,
  anomalyData,
  metricMeasure,
  universeQueryData,
  appName,
  timezone,
  graphData,
  graphQueryParams,
  onSelectAshLabel
}: QueryDataViewProps) => {
  const classes = useStyles();

  // Filter and find the query for which the data is being displayed
  const queryObject = universeQueryData?.find((data: any) => {
    return data.id.queryId === queryId?.[0];
  });
  const query = queryObject?.query;

  return (
    <Box mt={3} mr={4}>
      <Typography variant="h4" className={classes.queryText}>
        {query}
      </Typography>
      <YBPanelItem
        body={graphData?.map((data: any) => {
          const operations = getOperations(
            metricMeasure,
            data,
            GraphType.MAIN,
            true,
            graphQueryParams,
            true
          );

          return (
            <Box mt={2} mb={2}>
              <SecondaryDashboard
                metricData={data}
                metricKey={
                  data.name?.startsWith('active_session_history')
                    ? `${data.name}-${Math.random() * 1000}`
                    : data.name
                }
                containerWidth={null}
                prometheusQueryEnabled={true}
                metricMeasure={metricMeasure}
                operations={
                  metricMeasure === MetricMeasure.OVERALL ? [] : operations.uniqueOperations
                }
                groupByOperations={operations.groupByOperations}
                shouldAbbreviateTraceName={true}
                isMetricLoading={false}
                anomalyData={anomalyData}
                appName={appName}
                timezone={timezone}
                graphType={GraphType.MAIN}
                queryData={universeQueryData}
                onSelectAshLabel={onSelectAshLabel}
                isAdvancedView={true}
              />
            </Box>
          );
        })}
      />
    </Box>
  );
};
